#!/bin/bash

### Vars
USAGE="Launch the Python unit tests for one or several modules using oe (openerp-command).\n
Create a database if the database doesn't exist and install modules.
\n
test --module module\n
\n
Options:\n
--module [required]: modules to test;\n
--db-name [optional]: force the name of the database otherwise 
    the name will be 'test__<module_name>';\n
--drop [optional]: drop database if exists;\n
--help: display this help\n

Call : sudo su openerp -c"" ./test.sh --module=pos_invoicing""
"
oe_command=./openerp-command/oe
oe_server=./ocb-server/openerp-server
db_prefix="test__"
db_login="openerp"
addons_path="./ocb-addons/,./ocb-web/addons/,./openerp-addons-grap"
python_path=$PWD"/ocb-server/"

### Get params
module=''
drop=false
for arg in "$@"
do
    if [ ${arg:0:9} == '--module=' ]; then module=${arg:9}; fi
    if [ ${arg:0:10} == '--db-name=' ]; then db_name=${arg:10}; fi
    if [ ${arg:0:6} == '--drop' ]; then drop=true; fi
done

### Init
echo "Parameter --module : '"$module"'"
echo "Parameter --drop : '"$drop"'"
if [ -z $db_name ]
then
    db_name=${db_prefix}$module
    echo "Parameter --db-name : '"$db_name"' (autogenerated)"
else
    echo "Parameter --db-name : '"$db_name"'"
fi

echo "-------------------------------------------------------------------------"

### Manage Database
# Test if database exist and drop database if asked
db_exist=$(psql -l | grep -w "$db_name" | wc -l)
if [ $db_exist == 1 ] && [ $drop == true ]; then
    echo "Dropping database '"$db_name"'"
    dropdb $db_name
    db_exist=0
fi
# Create new database if required
if [ $db_exist == 0 ]; then
    createdb -O $db_login $db_name
    $oe_server --init=$module  --stop-after-init --database=$db_name --addons-path=$addons_path
fi

### Run Test TODO : realize multi test.
export PYTHONPATH=$PYTHONPATH:$python_path
$oe_command run-tests --database=$db_name --addons=$addons_path --module=$module
